from distutils.core import setup
setup(
    name = 'fricles',
    packages = ['fricles'], # this must be the same as the name above
    version = '0.32',
    description = 'Client library to extract sentiments from text',
    author = 'Chetan Ganjihal',
    author_email = 'chetan@humdingerlabs.com',
    url = 'https://github.com/supertramped/fricles-client', # use the URL to the github repo
    download_url='https://github.com/supertramped/fricles-client/releases/tag/0.32',
    keywords = ['fricles'], # arbitrary keywords
    classifiers = [],
)
